==> huaweicloudsdkdcs-3.0.49-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/update_bigkey_autoscan_config_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class UpdateBigkeyAutoscanConfigResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'enable_auto_scan': 'bool',
        'schedule_at': 'list[str]',
        'updated_at': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'enable_auto_scan': 'enable_auto_scan',
        'schedule_at': 'schedule_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, instance_id=None, enable_auto_scan=None, schedule_at=None, updated_at=None):
        """UpdateBigkeyAutoscanConfigResponse - a model defined in huaweicloud sdk"""
        
        super(UpdateBigkeyAutoscanConfigResponse, self).__init__()

        self._instance_id = None
        self._enable_auto_scan = None
        self._schedule_at = None
        self._updated_at = None
        self.discriminator = None

        if instance_id is not None:
            self.instance_id = instance_id
        if enable_auto_scan is not None:
            self.enable_auto_scan = enable_auto_scan
        if schedule_at is not None:
            self.schedule_at = schedule_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def instance_id(self):
        """Gets the instance_id of this UpdateBigkeyAutoscanConfigResponse.

        实例ID

        :return: The instance_id of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this UpdateBigkeyAutoscanConfigResponse.

        实例ID

        :param instance_id: The instance_id of this UpdateBigkeyAutoscanConfigResponse.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def enable_auto_scan(self):
        """Gets the enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.

        是否开启自动分析

        :return: The enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: bool
        """
        return self._enable_auto_scan

    @enable_auto_scan.setter
    def enable_auto_scan(self, enable_auto_scan):
        """Sets the enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.

        是否开启自动分析

        :param enable_auto_scan: The enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.
        :type: bool
        """
        self._enable_auto_scan = enable_auto_scan

    @property
    def schedule_at(self):
        """Gets the schedule_at of this UpdateBigkeyAutoscanConfigResponse.

        每日分析时间，时间格式为21:00

        :return: The schedule_at of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: list[str]
        """
        return self._schedule_at

    @schedule_at.setter
    def schedule_at(self, schedule_at):
        """Sets the schedule_at of this UpdateBigkeyAutoscanConfigResponse.

        每日分析时间，时间格式为21:00

        :param schedule_at: The schedule_at of this UpdateBigkeyAutoscanConfigResponse.
        :type: list[str]
        """
        self._schedule_at = schedule_at

    @property
    def updated_at(self):
        """Gets the updated_at of this UpdateBigkeyAutoscanConfigResponse.

        配置更新时间，时间格式为2020-06-15T02:21:18.669Z

        :return: The updated_at of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this UpdateBigkeyAutoscanConfigResponse.

        配置更新时间，时间格式为2020-06-15T02:21:18.669Z

        :param updated_at: The updated_at of this UpdateBigkeyAutoscanConfigResponse.
        :type: str
        """
        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateBigkeyAutoscanConfigResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdcs-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/update_bigkey_autoscan_config_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class UpdateBigkeyAutoscanConfigResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'enable_auto_scan': 'bool',
        'schedule_at': 'list[str]',
        'updated_at': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'enable_auto_scan': 'enable_auto_scan',
        'schedule_at': 'schedule_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, instance_id=None, enable_auto_scan=None, schedule_at=None, updated_at=None):
        """UpdateBigkeyAutoscanConfigResponse - a model defined in huaweicloud sdk"""
        
        super(UpdateBigkeyAutoscanConfigResponse, self).__init__()

        self._instance_id = None
        self._enable_auto_scan = None
        self._schedule_at = None
        self._updated_at = None
        self.discriminator = None

        if instance_id is not None:
            self.instance_id = instance_id
        if enable_auto_scan is not None:
            self.enable_auto_scan = enable_auto_scan
        if schedule_at is not None:
            self.schedule_at = schedule_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def instance_id(self):
        """Gets the instance_id of this UpdateBigkeyAutoscanConfigResponse.

        实例ID

        :return: The instance_id of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this UpdateBigkeyAutoscanConfigResponse.

        实例ID

        :param instance_id: The instance_id of this UpdateBigkeyAutoscanConfigResponse.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def enable_auto_scan(self):
        """Gets the enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.

        是否开启自动分析

        :return: The enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: bool
        """
        return self._enable_auto_scan

    @enable_auto_scan.setter
    def enable_auto_scan(self, enable_auto_scan):
        """Sets the enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.

        是否开启自动分析

        :param enable_auto_scan: The enable_auto_scan of this UpdateBigkeyAutoscanConfigResponse.
        :type: bool
        """
        self._enable_auto_scan = enable_auto_scan

    @property
    def schedule_at(self):
        """Gets the schedule_at of this UpdateBigkeyAutoscanConfigResponse.

        每日分析时间，时间格式为21:00

        :return: The schedule_at of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: list[str]
        """
        return self._schedule_at

    @schedule_at.setter
    def schedule_at(self, schedule_at):
        """Sets the schedule_at of this UpdateBigkeyAutoscanConfigResponse.

        每日分析时间，时间格式为21:00

        :param schedule_at: The schedule_at of this UpdateBigkeyAutoscanConfigResponse.
        :type: list[str]
        """
        self._schedule_at = schedule_at

    @property
    def updated_at(self):
        """Gets the updated_at of this UpdateBigkeyAutoscanConfigResponse.

        配置更新时间，时间格式为2020-06-15T02:21:18.669Z

        :return: The updated_at of this UpdateBigkeyAutoscanConfigResponse.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this UpdateBigkeyAutoscanConfigResponse.

        配置更新时间，时间格式为2020-06-15T02:21:18.669Z

        :param updated_at: The updated_at of this UpdateBigkeyAutoscanConfigResponse.
        :type: str
        """
        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateBigkeyAutoscanConfigResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
